aboutsummaryrefslogtreecommitdiffstats
path: root/src/lib/base/symkey.h
diff options
context:
space:
mode:
authorJack Lloyd <[email protected]>2016-12-11 15:28:38 -0500
committerJack Lloyd <[email protected]>2016-12-18 16:48:24 -0500
commitf3cb3edb512bdcab498d825886c3366c341b3f78 (patch)
tree645c73ec295a5a34f25d99903b6d9fa9751e86d3 /src/lib/base/symkey.h
parentc1dd21253c1f3188ff45d3ad47698efd08235ae8 (diff)
Convert to using standard uintN_t integer types
Renames a couple of functions for somewhat better name consistency, eg make_u32bit becomes make_uint32. The old typedefs remain for now since probably lots of application code uses them.
Diffstat (limited to 'src/lib/base/symkey.h')
-rw-r--r--src/lib/base/symkey.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/lib/base/symkey.h b/src/lib/base/symkey.h
index c780e5239..dc523f82e 100644
--- a/src/lib/base/symkey.h
+++ b/src/lib/base/symkey.h
@@ -26,19 +26,19 @@ class BOTAN_DLL OctetString
size_t size() const { return m_data.size(); }
/**
* @return this object as a secure_vector<byte>
*/
- secure_vector<byte> bits_of() const { return m_data; }
+ secure_vector<uint8_t> bits_of() const { return m_data; }
/**
* @return start of this string
*/
- const byte* begin() const { return m_data.data(); }
+ const uint8_t* begin() const { return m_data.data(); }
/**
* @return end of this string
*/
- const byte* end() const { return begin() + m_data.size(); }
+ const uint8_t* end() const { return begin() + m_data.size(); }
/**
* @return this encoded as hex
@@ -75,22 +75,22 @@ class BOTAN_DLL OctetString
* @param in is an array
* @param len is the length of in in bytes
*/
- OctetString(const byte in[], size_t len);
+ OctetString(const uint8_t in[], size_t len);
/**
* Create a new OctetString
* @param in a bytestring
*/
- OctetString(const secure_vector<byte>& in) : m_data(in) {}
+ OctetString(const secure_vector<uint8_t>& in) : m_data(in) {}
/**
* Create a new OctetString
* @param in a bytestring
*/
- OctetString(const std::vector<byte>& in) : m_data(in.begin(), in.end()) {}
+ OctetString(const std::vector<uint8_t>& in) : m_data(in.begin(), in.end()) {}
private:
- secure_vector<byte> m_data;
+ secure_vector<uint8_t> m_data;
};
/**
@@ -26,19 +26,19 @@ class BOTAN_DLL OctetString
size_t size() const { return m_data.size(); }
/**
- * @return this object as a secure_vector<byte>
+ * @return this object as a secure_vector<uint8_t>
*/